#
# spec file for package daps
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           daps
Version:        3.3.2
Release:        1.10

%define docbuilddir    %{_datadir}/daps

Summary:        DocBook Authoring and Publishing Suite
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Productivity/Publishing/XML
URL:            https://github.com/openSUSE/daps
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}.rpmlintrc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildArch:      noarch

BuildRequires:  ImageMagick
BuildRequires:  automake
BuildRequires:  bash >= 4
BuildRequires:  dia
BuildRequires:  docbook-xsl-stylesheets >= 1.77
BuildRequires:  docbook_4
BuildRequires:  docbook_5
BuildRequires:  fdupes
BuildRequires:  inkscape
BuildRequires:  jing
BuildRequires:  libxml2-tools
BuildRequires:  libxslt
BuildRequires:  libxslt-tools
BuildRequires:  poppler-tools
BuildRequires:  python3-lxml
BuildRequires:  suse-xsl-stylesheets
BuildRequires:  svg-dtd
BuildRequires:  xerces-j2
BuildRequires:  xml-apis
BuildRequires:  xmlgraphics-fop >= 0.94
BuildRequires:  xmlstarlet
BuildRequires:  rubygem(%{rb_default_ruby_abi}:asciidoctor)

# In order to keep the requirements list as short as possible, only packages
# needed to build EPUB, HTML and PDF are really required
# All other packages required for editing or more exotic output formats
# are recommended rather than required

PreReq:         libxml2
PreReq:         sgml-skel

Requires:       ImageMagick
Requires:       bash >= 4
Requires:       dia
Requires:       docbook-xsl-stylesheets >= 1.77
Requires:       docbook5-xsl-stylesheets >= 1.77
Requires:       docbook_4
Requires:       docbook_5
Requires:       inkscape
Requires:       java >= 1.8.0
Requires:       jing
Requires:       libxslt
Requires:       make
Requires:       poppler-tools
Requires:       python3-lxml
Requires:       suse-xsl-stylesheets
Requires:       svg-schema
Requires:       xerces-j2
Requires:       xml-apis
Requires:       xmlgraphics-fop >= 0.94
Requires:       xmlstarlet
Requires:       zip
Requires:       rubygem(%{rb_default_ruby_abi}:asciidoctor)

Recommends:     aspell-en
Recommends:     calibre
Recommends:     ditaa
Recommends:     epubcheck
Recommends:     exiftool
%ifarch aarch64 %{ix86} x86_64
Recommends:     libreoffice-draw
%endif
Recommends:     optipng
Recommends:     perl-checkbot
Recommends:     remake
Recommends:     suse-doc-style-checker
Recommends:     suse-documentation-dicts-en
Recommends:     w3m
Recommends:     xmlformat

# Internal XEP package:
Suggests:       xep

%description
DocBook Authoring and Publishing Suite (DAPS)

DAPS contains a set of stylesheets, scripts and makefiles that enable
you to create HTML, PDF, EPUB and other formats from DocBook XML with a
single command. It also contains tools to generate profiled source
tarballs for distributing your XML sources for translation or review.

DAPS also includes tools that assist you when writing DocBook XML:
validator, link checker, spellchecker, editor macros and stylesheets for
converting DocBook XML.










#--------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}

# Correct shebang line as suggested in
# https://lists.opensuse.org/opensuse-packaging/2018-03/msg00017.html
sed -i '1 s|/usr/bin/env python|/usr/bin/python|' libexec/daps-xmlwellformed \
  libexec/getentityname.py \
  libexec/validate-tables.py

#--------------------------------------------------------------------------
%build
%configure --docdir=%{_defaultdocdir}/%{name} --disable-edit-rootcatalog
%__make %{?_smp_mflags}

#--------------------------------------------------------------------------
%install
make install DESTDIR=$RPM_BUILD_ROOT

# create symlinks:
%fdupes -s $RPM_BUILD_ROOT/%{_datadir}

#----------------------
%post
update-xml-catalog
exit 0

#----------------------
%postun
update-xml-catalog
exit 0

#----------------------
%posttrans

#----------------------
%files
%defattr(-,root,root)

%dir %{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_defaultdocdir}/%{name}

%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%dir %{_datadir}/%{name}
%dir %{_datadir}/xml/%{name}
%dir %{_datadir}/xml/%{name}/schema

# Catalogs
%config %{_sysconfdir}/xml/catalog.d/%{name}.xml

# Config files
%config %{_sysconfdir}/%{name}/*

# Man/Doc
%doc %{_mandir}/man1/*.1%{ext_man}
%doc %{_defaultdocdir}/%{name}/*

%{_bindir}/*
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/emacs/site-lisp/docbook_macros.el
%{_datadir}/xml/daps/schema/*
%{docbuilddir}
#----------------------

%changelog
* Tue Oct 25 2022 Frank Sundermeyer <fsundermeyer@opensuse.org>
  Stable release DAPS 3.3.2:
  * Bug fixes:
  - Make DAPS work with libslt > 1.1.34
    (https://github.com/openSUSE/daps/issues/679)
  - Profiling no longer requires processing instruction
  - if DC-file/command line contains profile settings the
    profiling stylesheets will autoimatically be applied
    (https://github.com/openSUSE/daps/issues/529)
  - FOP support for google noto-sans fonts (for Japanese, Korean,
    traditional & simplified Chinese)
    (https://github.com/openSUSE/daps/issues/684)
  - Fix validation error where errors were ignored or failed with a
    bash error
    (https://github.com/openSUSE/daps/issues/679)
  - unpacking locdrops automatically removes dm:editurl from
    docmanager XML header (if present)
  - Building parts of a document (with --rootid) is no longer
    supported when rootid points to a section or sect1 (because
    depending on HTML chunkling, this may result in an empty
    document)
    (https://github.com/openSUSE/daps/issues/686)
  * Helper scripts:
  - Added a few scripts for handling SUSE localization branches,
    improving SEO and migrating frm DocBook4 to DocBook5
  - can be found in the sources under contrib/ (not included in
    SUSE packages)
  * Obsoletes patch daps-fix-build-against-libxslt-1.1.36+.patch
* Mon Oct 17 2022 David Anes <david.anes@suse.com>
  * Add patch to build against libxslt 1.1.36+:
  - In libxslt >=1.1.35, the XSLT processor changed the resolution
    strategy. It gets two template rules (xi:include/@href and
    xi:include/@*) with the same priority (0.5). That's why we need
    to lower the priority to zero for xi:include/@*
  - Added patch "daps-fix-build-against-libxslt-1.1.36+.patch"
* Mon Feb 14 2022 Stefan Knorr <sknorr@suse.com>
- Stable release DAPS 3.3.1:
  * Bug fixes:
  - Added `--not-validate-tables` parameter that disables extended
    table validation to additional targets
* Mon Feb  7 2022 Stefan Knorr <sknorr@suse.com>
- Stable release DAPS 3.3.0:
  * New features:
  - DocBook table validation is now enabled by default as part of
    validation and building (#532)
  - Improved validation to always check XML validity, tables,
    images, and IDs, rather than stopping after the first issue
    occurs
  - Set up Poppins font in FOP config delivered with DAPS
  * Bug fixes:
  - Fixed validation failures occurring because `--verbose` was set
  - Fixed xml-wellformedness check to use a non-zero exit code
    when entity definitions are missing (#539)
  - Improved image check during validation to check within context
    of entire set, not just current root ID (#627)
  - Fixed output of missing/duplicated image list displayed during
    build (#634)
  - Fixed paths to entity files in `unpack-locdrop`
  - Fixed output of `daps -v` when there is no XSL-FO formatter
    installed (#622)
  - Fixed `daps spellcheck --help` output
  - Improved messages for `unpack-locdrop` and other subcommands
  * Removed features:
  - Removed unused `process-xrefs` and `checkconformance`
    stylesheets (#612)
  * Repository changes:
  - Integrated Python tooling and tests for `xml-wellformed` and
    `getentityname`
* Thu Jun 10 2021 Stefan Knorr <sknorr@suse.com>
- Stable release DAPS 3.2.0:
  * New features:
  - Added config file compatible with xmlformat 1.9 (for the
    xmlformat version from github.com/someth2say/xmlformat)
  - Added DocBook table validation script (must be run manually
    currently)
  * Bug fixes:
  - Properly enabled `--validate-ids` and `--validate-images`
    validation options
  - For consistency/compatibility, output PDFNAME deprecation
    message to stderr
  - In AsciiDoc postprocess stylesheet, fixed handling of
    subtitles
  - Removed remaining references to Ghostscript (#614)
  * Removed features:
  - Remove `html --jsp` target that was unused for years (#609)
  - Removed the `online-docs` target and associated DocBook 5-to-4
    conversion stylesheets (#610)
  - Removed code to query SVN properties that was unused for years
    (#611)
* Fri May 21 2021 Stefan Knorr <sknorr@suse.com>
- Stable release DAPS 3.1.2:
  * Bug fixes:
  - Fixed issue where irrelevant XIncludes would cause validation
    errors (#617)
  * Documentation:
  - Updated installation documentation
* Wed May 12 2021 Stefan Knorr <sknorr@suse.com>
- Stable release DAPS 3.1.1:
  * Bug fixes:
  - Removed error messages that appeared during command-line
    completion
  * Packaging changes:
  - Updated Spec file from OBS repo
* Tue May 11 2021 Stefan Knorr <sknorr@suse.com>
- Stable release DAPS 3.1.0:
  * New features:
  - Allow converting AsciiDoc books with multiple parts into a
    DocBook set (`--adocset`/`ADOC_SET="yes"`)
  - Remove `dm:docmanager` during `unpack-lockdrop` when
    `--remove-dm` is used
  - Added support for DITAA diagrams as an image format (must be
    added as an external file) (#540)
  - Allow using `{daps-adoc-attribute}` from AsciiDoc sources to
    add a list of all AsciiDoc attributes used by DAPS to the
    output (#573)
  - Added `daps validate` options  `--validate-ids` (checks
    whether IDs match a basic SEO-compatible set of characters) and
    `--validate-images` (checks for missing and duplicated images)
  - Renamed `daps checklink` to `daps linkcheck` for consistency
    with `daps spellcheck` and `daps stylecheck`
  - Renamed `PDFNAME` to `OUTPUTNAME` DC file option to clarify
    its purpose
  * Removed features:
  - Removed support for the Xfig (`.fig`), PDF, and EPS image
    formats
  - Removed support for the `asciidoc` tool, DAPS now only supports
    AsciiDoctor
  - Removed support for `--xsltparam` which has been replaced by
    `--stringparam`
  - Removed `--css=none` option of `daps epub`
  - Removed `daps-auto.pl` which has been replaced by
    `daps-autobuild`
  - Removed all support for Python 2 dependencies
  * Bug fixes:
  - When AsciiDoctor outputs a warning, DAPS will now fail,
    avoiding XML issues that would crop up later (this only works
    if AsciiDoctor >= 1.5.7 is used)
  - Find unresolvable AsciiDoc attribute references (such as
    `{reference}`) and error out rather than adding them to the
    output
  - When converting AsciiDoc, always unset the `imagesdir`
    attribute, so DAPS can mandate its own `images` directory
  - On successive DAPS runs, always convert AsciiDoc files to XML
    again
  - Improved default IDs generated by AsciiDoctor, to avoid leading
    underscores in IDs (#520)
  - Improved AsciiDoc `postprocess.xsl` clean-up stylesheet:
  - Rewrite `@contentwidth` to `@width`
  - Improved display of article titles
  - Fixed validation of generated abstract elements
  - Improved workarounds for `authorinitials`, `othername`,
    `lineage`
  - Output AsciiDoc `<<reference, title>>` construct as
    `title (<xref linkend="reference"/>)` (same for links)
  - Improved handling of slightly misused AsciiDoc block/
    example syntax that was previously converted to
    GeekoDoc-incompatible `formalpara` elements
  - Fixed updating of profiled files when an entity or the DC
    file of the source has changed
  - Only use AsciiDoctor's `--failure-level` if the version of
    AsciiDoctor is new enough to support it
  - Allowed use of AsciiDoc attributes defined on command line
    and in DC file at the same time
  - Made DAPS's default set of AsciiDoc attributes overridable
  - Internally handle `--param` the same as `--stringparam` (#589)
  - Made sure that both `index.html` and `[ROOTID].html` are
    generated during HTML builds
  - Reworked `getentityname.py` (#556)
  - Restored compatibility with Novdoc profiling stylesheet
    references
  - Avoid stumbling over empty hrefs in XIncludes during validation
  - Fixed issue where DC file parser would concatenate rather
    than overwrite values
  - Fixed issue where DC file parser would not correctly recognize
    last line of a DC file if it did not end in a newline character
    (#553)
  - Fixed issue where default entities like `&mdash;` could not
    be found
  - Fixed `unpack-locdrop` runs that failed because file lists
    contained spaces rather than line breaks
  - Use `PROFOS` value during `locdrop`
  - Fixed `daps html --nostatic` build failure resulting from
    identical files error
  - Fixed GNU Make 4.3 `+=` operator compatibility
  - Added compatibility with Inkscape 1.0 command-line options
  - Set initial memory for FOP
  - Fixed path to Avalon Framework (bsc#1175214)
  - Fixed LibreOffice Draw executable name for Debian (#564)
  - Improved error message when MAIN file is missing (#494)
  - Improved error message displayed when ROOTID does not exist in
    the document (#546)
  - Show FOP warnings when running with `-vv` or higher verbosity
  - Suppressed error messages about missing `xml:base` during
    `daps linkcheck` (#558)
  - Improved message output of `daps-xmlwellformed`
  - Improved Git updating flow in `daps-autobuild`
  * Documentation:
  - Added man pages for `daps-xmlformat` and `daps-check-deps`
    (#491)
  - Added documentation for generating a DocBook set from an
    AsciiDoc book
  - Fixed typos and other minor issues throughout the documentation
  * Packaging changes:
  - Cleaned up TAR archives generated by GitHub (#489)
  - Do not make libexec XSL files executable (#492)
* Thu Apr  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add daps-gnu-make-4.3.patch: Fix compatibility with GNU Make 4.3.
* Mon Jan  6 2020 Fridrich Strba <fstrba@suse.com>
- Do not depend on xml-commons-jaxp-1.3-apis, but on generic
  xml-apis provider
* Mon Dec  3 2018 fsundermeyer@opensuse.org
- Updated license statement in spec file to SPDX 3.3 notation
* Wed Nov 21 2018 fsundermeyer@opensuse.org
-  Only recommend libreoffice-draw on aarch64 %%{ix86} x86_64
* Thu Nov  8 2018 fsundermeyer@opensuse.org
  Public/final release DAPS 3.0.0
  * New Features:
  - added support for ASCIIDOC sources
  - added support for LibreOffice Draw images (*.odg)
  - added support for specifying a config file on the command line
    (with --config)
  - added SVG support for HTML builds
  - integrated hunspell and make aspell optional
  - initial well-formedness check ignores duplicated IDs (this
    allows to have identical IDs in parts that get profiled)
  - initial well-formedness warns about missing xi:include files
  - daps-autobuild now supports building single books (via the
  - -dcfiles option)
  - DAPS prgram name and version are passed to stylesheets with
    xslt parameters "converter.name" and "converter.version"
  - implement file not found for XIncludes
  - FOP and XEP version numbers are shown in debug/verbose output
  - various improvements for the DocBook to NovDoc conversion
  - split lib/daps_functions into several files to improve speed
    and maintainability
  * Bugfixes:
  - #476: DAPS generates ODG->SVG files into images/src
  - #475: Tab completion creates error
  - #474: Potentially wrong variable assignment
  - #437: lodraw tries to convert empty SVG
  - #469: RPMLINT complains about permissions of XSLT stylesheet
  - #468: xmlwellformed script creates RPMLINT warning
  - #466: Build issues with daps-xmlwellformed
  - #464: xmlformat incorrectly formats variablelist terms
  - #462: Implement file not found for XIncludes
  - #459: By default, use the xep-daps.xml configuration from
    stylesheets
  - #457: Ship the asciidoc postprocessing stylesheet
  - #455: Transform glosslist into variablelist (NovDoc conversion)
  - #453: Cleanup stylesheet for results from ASCIIDoctor
  - #452: Make it possible to specify the ASCIIDOC doc type
  - #439: Make xmlformat more verbose in debug mode
  - #435: require java-devel >= 1.8.0
  - #425: Well-formedness check fails with double occurrences
    of xml:ids
  - #424: Fix XML catalog generation
  - #422: Integrate hunspell and make aspell optional
  - #421: Show FOP and XEP version in debug/verbose output
  - #419: HTML and PDF builds need different paths for Admonition
    and Callout Images
  - #416: DAPS Won't Built With UTF-8 Characters in XML Filenames
  - #415: Add support for LibreOffice Draw files
  - #397: Spaces in path problem
  - #322: Add documentation for  --xmlonly / --imgonly switches
    for the list-srcfiles subcommand
  - #226: Let stylesheets know which version of DAPS calls them
  - #119: daps-init: also include example for set
  - show a warning when an existing PDF has a size of 0 bytes
    (usually the result of a failed FOP build)
  - PDF fails when static links in build/.tmp already exist
  - fixed DocBook identifiers in configure.ac
  - made unpack-lopcdrop more robust against non-critical issues;
    improved its debugging output
  * Documentation:
  - new guide: ASCIIDOC Quick Start
  - Various updates to reflect changes in the code
  - Improve help text for daps-xslt
  - Improve error message for IDs defined multiple times
  * Removed support for:
  - sourcing DC-files
  - help texts for deprecated daps 1.x commands
  * Misc:
  - converted Python scripts to Python 3; changed build
    dependencies to python3
* Tue Oct 23 2018 sknorr@suse.com
- Workaround to make it possible to build things
* Fri Oct 19 2018 rick.salevsky@suse.com
  Stable release DAPS 3.0.0:
  * New Features:
  - added full support for Python3
  - added SVG support for online-docs
  - added support to build AsciiDoc documentation
  - integrated hunspell and make aspell optional
  - implement file not found for XIncludes
  * Bugfixes:
  - #419: HTML and PDF builds need different paths for Admonition
  and Callout Images
  - #322: Add --xmlonly / --imgonly switches to list-srcfiles
  - #416: DAPS Won't Built With UTF-8 Characters in XML Filenames
  - #397: Spaces in path problem
  - #469: RPMLINT complains about permissions of XSLT stylesheet
  - #464: xmlformat incorrectly formats variablelist terms
  - #466: Build issues
  - #475: Tab completion creates error
  - PDF fails when static links in build/.tmp already exist
  * Documentation:
  - Various updates to reflect changes in the code
  - Improve help text for daps-xslt
* Tue Jun 20 2017 fsundermeyer@opensuse.org
- another try to get the Changelogs for openSUSE and SLES aligned
  (no code changes)
* Wed Jun 14 2017 fsundermeyer@opensuse.org
  Hotfix for 2.4.0:
- fixed fatal typo in lib/daps-functions
- fixed spelling/grammar issues in error messages
  Changelog:
- merged SLE 12 and Factory Changelogs
- remove daps-dont-complain-about-deprecated-option.patch
* Tue May 30 2017 fsundermeyer@opensuse.org
  Stable release DAPS 2.4.0:
  * New Features:
  - added a dependency checker for DAPS (/usr/bin/daps-check-deps)
    that makes it easy to check for missing programs/packages
  - added a "--lean" parameter to PDF generation for creating PDFs
    with a reduced file size (by reducing the quality of included
    images); useful for sharing PDFs via e-mail
  - added a srylesheet for returning all IDs from an XML file
    (daps-xslt/common/get-all-xmlids.xsl)
  * Bugfixes:
  - #408: The list-file-* commands now work with ROOTIDs from all
  possible elements
  - #390: When an ID appears twice in the XML and this ID is used
  with --rootid, DAPS's error message is unhelpful
  - #365: Improved error messages on "File not found" errors
    (now tells whether the path was provided by command-line
  or config file)
  - #371: Make path to the xmlformat config file configurable
  - #372: Adjusted debian dependency list
  - #373: Check unpack-locdrop
  - #379: Output error of list-images-multisrc with
    pretty | wc option
  - #380: Proper error messages when binaries/packages are missing
  - #392: daps-xmlformat writes name of config file into output
  - SVGs were not included in ePUBs
    (https://bugzilla.suse.com/show_bug.cgi?id=1006204)
  - Setting a default value for db5_version in configure.ac
    otherwise the DB5 URN in etc/config will be set to an invalid
    value if DB5 is not installed when running make
  - fixed a few minor issues with the config file parser that was
    introduced with 2.3.0 (among them #387)
  - Increased Java stacksize for jing
  - Improved the DocBook5 -> DocBook 4 (-> NovDoc) conversion
  - compatibility: Debian's version of "which" does not support
    long parameters
  * Documentation:
  - Various updates to reflect changes in the code
  - #345: added documentatioon for the xmlformat subcommand
  - #362: added documentation for the --jobs option
  - #363: added documentation about building a bigfile from
    invalid sources
  - #364: added documentation for the --norefchecks option
  - #403: improved documentation about stylesheet customizing
    (also see #407)
  - #404: clarify doc about listing unused images
  - completely revised the doc (spelling, language and grammar)
  - doc is not yet 100%% on par with the code, but we are getting
    closer
  * Compatibility:
  - successfully tested DAPS on Linux Mint 18.1
* Wed Oct  5 2016 sknorr@suse.com
- Try to fix broken link
- Remove SVN fetch source script
* Tue Aug  9 2016 fs@suse.com
- Increased the Java Stacksize for jing to 4096k since otherwise
  building manuals on s390x is failing, see bsc#992755
* Thu Aug  4 2016 fsundermeyer@opensuse.org
  Stable release DAPS 2.3.0:
  Just to please the SLES submission bot: bsc#992546
  * New Features:
  - Config File Parser:
    Up to now, config files (DC-files, /tec/daps/config and
    ~/.config/daps/dapsrc) have been sourced. This has been a major
    security issue, since every shell code gets executed when a file
    is being sourced. DAPS 2.3.0 now comes with a parser that fixes
    this security hole. Apart from one exception (see below) existing
    config files do _not_ need to be changed. However, the parser
    offers more flexibility, see
    https://github.com/openSUSE/daps/blob/develop/etc/config.in
    for documentation (the manuals has not been upfdated, yet).
    The only exception that requires changes in the config file is
    something like FOO="$FOO bar" To concatenate values, use "+="
    now. See the following commit for an example:
    https://github.com/openSUSE/daps/commit/7a2ce04
  - Bash Completion:
    TAB-completion for DAPS has been one of the very first feature
    requests we opened (almost five years ago). Now we finally
    managed to conquer the black Bash magic required to get it!
  - Automatically detect the DocBook 5 version: If you have
    DocBook 5.1 installed, docbookxi.rng from 5.1 will
    automatically be used as the validating schema for DocBook 5
    documents. If you rather want to use the 5.0 schema
    or a custom schema, set DOCBOOK5_RNG_URI accordingly in
    /etc/daps/config (for a system wide configuration), in
    $HOME/.config/daps/dapsrc (for a user specific configuration),
    or in the DC-file (for a document-specific configuration)
  * Bugfixes:
  - subcommand "locdrop" failed when the book did not include
    images
  - spellcheck now ignores text in <replaceable> tags
  - obsolete daps-susespell has been removed (replaced by
    daps ... spellcheck long ago)
  - paths starting with "~" were not always correctly resolved
  - several fixes for ePUB, among them a fix that now correctly
    chooses mediaobject entries with role="html" rather than
    choosing the first one listed ion the XML source
  - #10 : Generate TAB completion
  - #359: Drop bash 3 suppor
  - #369: Code review: Check Variable Assignments
  - #375: Issues with the xmlformat target
* Wed Jun 15 2016 fsundermeyer@opensuse.org
  Stable release DAPS 2.2.0:
  * New Features:
  - new subcommand "xmlformat" prettyfies the XML sources of a
    given DC-file or ROOTID using daps-xmlformat with
    /etc/daps/docbook-xmlformat.conf.
    (Note: this command will modify the original XML sources!)
  - SVG image support for HTML builds. To use it, make sure to
    provide the images in SVG format ad reference to them as follows:
    <imageobject role="html">
    <imagedata fileref="<SVG-FILE>" format="SVG"/>
    </imageobject>
  - the new global switch --jobs lets you specify how many parallel
    jobs to use. The default is set to the number of CPU cores (as was
    done in previous versions).
  - all commands generating file lists (e.g. "list-srcfiles") now
    generate human readable output on STDOUT. When the output goes
    to a pipe or subshell, it will be generated as a a one-liner.
  - Debugging of XML errors has been made easier. Sometimes the error
    message of the validator only points to an xi:include line, making
    it impossible to find the real location of the error. The option
  - -novalid for the target "bigfile" will create the bigfile
    without performing a validation check on the sources. A single XML
    will be built and validated. Now the error message points to the
    exact location of the error in the bigfile. From there it should be
    easy to find the error in the original sources.
  - Verbose and debugging output now also show all profiling
    attributes set in the DC-file, plus version information for
    the sytlesheets (if available)
  - added the option --norefchecks to all output-generating targets
    ("html", "pdf", ...), "validate", "bigfile" and others. Allows
    to build/validate documents without checking internal links
    (<... linkend="<ID>">).
  - subcommand "online-docs" now always converts the bigfile that is
    created to NovDoc. To keep the same format as the original
    sources, specify --dbnoconv. To create a DocBook4 bigfile from
    DocBook5 sources, specify --db5todb4.
  * Bugfixes:
  - #368: db4tonovdoc.xsl generates invalid NovDoc
  - #367: daps does not validate fop output
  - #366: Spellcheck trying to check the files "Cannot", "stat:", "No",
    "such", "file" ...
  - #364: DocBook5: Allow validating without checking xrefs
  - #363: Allow building a bigfile from invalid sources
  - #362: Make the number of parallel jobs configurable
  - #361: Externel xrefs are resolved to "????"
  - #360: Check Rootid fails on Debian 8.4.0
  - #356: file list output should default to pretty format
  - #354: Validate the result of online docs when it has been
    converted from DB5 to DB4 or novdoc
  - #353: Make db5 to db4 conversion default for online-docs
  - #351, #348, #342, #282: Fixes for the daps spec-file
  - #346: daps-xmlformat writes its messages into the output
  - #343: daps-init warning messages
  - #340: ePUB builds always show remarks
  - #335: on Debian, make install creates incorrect group in
    /etc/xml/config
  - #330: Enable SVG2Grayscale stylesheet to handle new color
    names
  - #305: locdrop produces no "non-trans" image tarball for a
    complete set
  - #301: SVG to PNG conversion creates very large PNGs
  - #289: Verbose / Debugging Output Should Show Profiling
    Attributes
  - #251: Write XSLT to Return xml-model PI
  - #226: Let stylesheets know which version of DAPS calls them
  - subcommand "clean-all" fails if run from within a directory
    that will be removed with that command
  - daps fails when called from a directory that no longer exists
  * Cross-Distribution Support
  - first release with full Debian/Ubuntu support--manual
    adjustments after the installation are no longer needed
    (was required in previous releases for DocBook5 support).
    Many thanks to Tomáš Bažant and Christoph Berg for their help!
  - GitHub checkouts now also work for Fedora/RedHat and
    Debian/Ubuntu--refer to
    https://github.com/openSUSE/daps/blob/develop/INSTALL.adoc
    for details
  - tested on Debian 8.5.0 / Fedora 23 / openSUSE 13.2 and
    Leap 42.1 / SUSE Linux Enterprise 12 / Ubuntu 16.0
  * Misc:
  - removed "daps-envconvert", a script for converting susedoc
    ENV-files to DAPS DC-files. susedoc was the predecessor of
    DAPS.
  * Documentation:
  - the documentation has _not_ been updated for this release, so
    new features mentioned above are not yet covered
* Sun Apr 17 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Mon Dec  7 2015 fsundermeyer@opensuse.org
  Stable release DAPS 2.1.5:
  * New Features:
  - parameters for text generation can be set in the config files
    via TXT_PARAMS or via --param/--stringparam on the command line
  - a change introduced in 2.0 made using the original DocBook
    stylesheets for text generation the default. Since this behavior
    is confusing and unexpected, it is reverted with this change:
  * the stylesheets configured via STYLEROOT or --styleroot are
    used by default for text generation
  * to ignore _any_ STYLEROOT definitions, set
    TXT_IGNORE_STYLEROOT="yes" in the config files or use
  - -ignore-styleroot on the command line
    (daps -d <DC> text --ignore-styleroot)
  * Bugfixes:
  - Fix for issue #294: xmlcatalog returns file:<PATH> rather than
    file://<PATH> on Debian Jessie and openSUSE Tumbleweed and
    caused DAPS to fail with DB5 sources
  * Misc
  - added basic debugging output to test suite (--debug)
* Wed Dec  2 2015 toms@opensuse.org
  Stable release DAPS 2.1.4:
  * Bugfixes:
  - Target text shows remarks (issue #293)
  - DAPS checklink doesn't work (issue #296)
  - ASPELL_EXTRA_DICT from ~/.config/daps/dapsrc is ignored
    (issue #297)
  - DAPS package includes SUSE wordlist (issue #298)
  - Parameter passed with --param is ignored with subcommand
    "text" (issue #299)
  - Target locdrop does not generate
    graphics-setfiles-$(DOCNAME)$(LANGSTRING).tar.bz2
    (issue #302)
  - Translation check for locdrop (issue #306)
  - Add --optipng to unpack-locdrop (issue #307)
  - Add --xmlonly / --imgonly switches to list-srcfiles (issue #310)
  - bigfile creates unresolved xrefs for  DocBook5 (issue #314)
  - Improve DocBook5 -> DocBook4 -> Novdoc Stylesheets (issue #311)
  - Enhancements in user guide, thanks to Martin Koeditz
    (issue #315)
  - FO contains wrong image paths when XML contains no profiling
    PI (issue #316)
  - DB-4-to-5 migration: missing book titles/productnames/productnumbers
    (issue #319)
  * New Features:
  - Option --schema lets you specify an URN to a DocBook 5 schema that
    is to be used for validation. Will be ignored when validating Docbbok4
    documents.
  - DOCBOOK5_STYLE_URI, DOCBOOK5_STYLE_URI, and DOCBOOK4_STYLE_URI may
    now also point to a local file. If the URN begins with the prefix
    "file://", it will not be resolved via xmlcatalog, but rather taken as
    is (minus "file://").
  - Add conversion options to online-docs:
    . --db5todb4: converts DocBook 5 sources to a DocBook 4 bigfile
    . --db5todb4nh: converts DocBook 5 sources to a DocBook 4
    bigfile without a DOCTYPE declaration
    . --dbtonovdoc: converts DocBook 4/5 to Novdoc
  * Misc:
  - Do not set -nocs, hurts us when building Arabic (related:
    issue #108)
  - Avoid adding version attribute on all elements (commit 3a273d5)
* Tue Sep 22 2015 fsundermeyer@opensuse.org
  Stable release DAPS 2.1.3:
  * Bugfixes:
  - Fix for issue #284 (spellcheck / getimages use wrong filelist
    when called with --debug
  - "--param" and "--stringparam" were missing for the subcommands
    package-pdf and package-html
  - all warning messages now go to STDERR, making it possible to
    always catch the output of a DAPS command with FOO="$(daps...)
  * Misc:
  - added a wrapper for jing allwing to customize java flags,
    jars, and options
  - standardized customising options for all java programs (fop,
    jing, xep)
* Wed Aug 26 2015 lchiquitto@suse.de
- Do not print warning about deprecated --xsltparam option to
  standard output.  At least some sub-commands (e.g, package-html)
  haven't been moved to the new method of passing parameters to
  the xslt processor, so it is incorrect to say it is deprecated.
  (bsc#943321)
* Tue Aug  4 2015 fsundermeyer@opensuse.org
-  Stable release DAPS 2.1.2:
  * Bugfixes
  - man page for daps-init was named daps_init
  * Miscellaneous:
  - renamed daps_autobuild to daps-autobuild for consistency
* Fri Jul 10 2015 fsundermeyer@opensuse.org
- Stable release DAPS 2.1.1:
  * Bugfixes:
  - Fix for issue #274 (PDF Index Building Fails Because of Empty
    Profiling Directory)
  - fix for issue #275 (Avoid Same Target Names in Different
    Makefiles)
  - fix for issue #276 (PROFILE_URN Detection Depends on Position of PI
    in Document)
  - fix for issue #277 (Debugging Targets Fail when xml:lang is
    not set)
  - fix for issue #278 (Avoid Using "LANGUAGE" as a Variable Name)
  - fix for issue #280 (Webhelp: Common/ Directory Contains Dead
    Symbolic Links)
  * New Features:
  - added support for profiling attribute "outputformat" by
    intrducing PROFOUTPUTFORMAT (issue #279)
  * Miscellaneous:
  - replaced Chinese font "FZSongTi" with "wqy-microhei" in the
    default config file for XEP
    (XEP_CONFIG_FILE=etc/xep/xep-daps.xml)
* Mon Jul  6 2015 fsundermeyer@opensuse.org
- no changes this version is just for the sake of the maintenance
  process: DAPS update is required by bsc #936253
* Thu Jul  2 2015 fsundermeyer@opensuse.org
  Stable release DAPS 2.1:
- added support for webhelp
- added support for <xi:include ... parse="text"> (issue #71)
- handling of passing XSLT parameters on the command line has been
  improved (issue #263)
- improved handling of doxcuments that do not need to be profiled
- daps_autobuild: changed the order of builds to increase performance
- Bugfix package-src: removed extraneous text
- Bugfix daps_autobuild: in case no rebuild was necessary, rsync
    deleted the previous results
- Bugfix DB4 -> DB5 migration: Fixed various issues in the migration
    stylesheet
* Fri Jun 19 2015 fsundermeyer@opensuse.org
  Stable release DAPS 2.0:
- supporting rng _and_ rnc schemas for validation with jing
- added a --debug switch and error reporting to daps_autobuild
- moved a --meta related warning so it does not get displayed
  when running a *-name subcommand
- fixed a quoting issue in daps-migrate and daps_functions
- fixed an error in the DB4->DB5 migration stylesheet (formatting
  was lost on <term> tags)
* Wed Jun 10 2015 fsundermeyer@opensuse.org
  New release DAPS 2.0~rc7
- replaced daps-auto.pl with daps_autobuild
  * uses an XML file as a config file (can be validated with
    schema that is also provided)
  * supports git _and_ svn repos
- DB5 fix for target productinfo
- locdrop target can now read information about translated files
  from in-file tag provided by docmanager
- fixed two issues in the unpack-locdrop target
- fixed stylesheet issues when using saxon as a parser
- Added missing dependency on $(RESULT_DIR) for epub
- bash code cleanup
- Changed default DB5 schema fom docbook.rng to docbookxi.rng
  (supports xi:includes)
- Documentation: now covers all 2.0 changes
* Mon Apr 27 2015 fsundermeyer@opensuse.org
  New release DAPS 2.0~rc6
  * Bugfix: Due to an error in Makefile.am, the contents of
  daps_xslt/relnotes were installed to daps_xslt/xhtml and
  vice versa.
* Tue Apr 21 2015 fsundermeyer@opensuse.org
  New release  DAPS 2.0~rc5
  (releases rc3 and rc4 have not been made available as SUSE builds)
- Full support for DocBook 5 now (finally)
- various fixes for ePUB (again):
  - ePUB 2 builds without warnings/errors in epubcheck
  - ePUB3 shows a few warnings/errors in epubcheck resulting from
  errors in the stylesheets
  - make sure ePUB gets a correct date format (YYYY-MM-DD)
- Moved DAPS user config directory to ~/.config/daps/. The config file
  has been renamed to dapsrc (the user will be notified and DAPS will
  automatically do the move if the user agrees)
- all of DocBook's profiling attributes are no supported
- Various build fixes to make it work on Debian Wheezy, Fedora 20/21
  openSUSE 13.x, SLE 12, and Ubuntu 14.10
- tested DAPS on Debian Wheezy, Fedora 20/21 and Ubuntu 14.10
- Added script and stylesheets to migrate DocBook4 projects to
  DocBook 5 (libexec/daps-migrate)
- various fixes and improvements for bin/daps-init (incl. man page)
- Added support for local static/ directories
- Established new locdrop workflow
- Fixed daps-init
- strings passed with --xsltparam no longer need to be uoted with double
  and single quotes--only use double quotes now
- Definied DAPS version for major, minor, and micro (configure.ac)
  - Introduced daps_version_{major,minor,micro} substitutions
  - Corrected URL from SourceForge to GitHub
  - Used DAPS version in AC_MSG_NOTICE
- Unified copyright statements
- Let configure change the Version in entity-decl.ent
- Created DOCTYPE and PI node manually for daps-xslt/profiling/
  stylesheets
- Added more testcases, fixed erfrors in test cases
- Significant documentation updates for version 2.0
- version string in manuals and man pages is now automatically set by
  configure/make
- provided useful READMEs in ASCII Doc format
- Support for both, /usr/bin/xml (SUSE) and /usr/bin/xmlstarlet (Ubuntu)
- stability fixes for make files
- adjusted the test suite to code changes; made sure all tests are passed
- man pages for daps-init, daps-susespell and daps-envconvert will
  now be correctly installed
- added various XSLT parameters to the documentation's DC-files to
  make them look better when build with the upstream stylesheets
  Bug fixes:
- issue #151: Detect DocBook XSL Stylesheet Version in daps
- issue #157: Add option for optimising PNG files for targets locdrop and
  package-src
- issue #223: Paths starting with ~ are now correctly resolved
- issue #227: Made --static for HTML builds the default
- issue #230: Moved DAPS config to ~/.config/daps/
- issue #249: Added support for all missing profiling attributes supported
  by DocBook
- issue #250: building Japanese text format requires external LANG
  setting
- issue #253: Implement Migration Stylesheets from DocBook 4 <-> DocBook 5
- issue #260: Removed project-web directory (moved into gh-pages branch)
- issue #262: Quoting is removed from subcommand-options
- issue #264: Make STYLEROOT Platform Independant
- issue #266: Review XEP config file handling
- issue #267: Improve Default DAPS Layout
- issue #268: Fix ePUB date issues
- check for embeeded fonts in PDF now works correctly
- ASPELL_LANG no longer gets overwritten with value from XML document if
  set in config or on the command line
- package-html no longer fails when called with --draft
- DocBook5 validation now works correctly
- epub is now correctly generated (STYLEIMG was not always set)
- existing man page builds were duplicated rather than overwritten
- callout graphics were not shown in PDF when using the
  DocBook stylesheets
  Project:
- project moved to GitHub
- Moved all stylesheet related files to github://openSUSE/suse-xsl
- obsolete docmanager code has been removed from the repository
- source clean-up
- source changes are tested with Travis
* Thu Aug 14 2014 sknorr@suse.de
- Purely packaging related update: update list of excluded files,
  streamline TAR archive fetch script
* Thu Aug 14 2014 sknorr@suse.de
  New release DAPS 2.0~rc2
-  EPUB 3 builds now succeed
-  Mobipocket builds succeed again
-  "static" directories are now expected to be located within
  specific subfolders of the chosen style root
-  EPUB now supports "static" folders
* Fri Aug  1 2014 fsundermeyer@opensuse.org
-  Changing the version number from "RC1" to "rc1" because the
  uppercase form is considered to be older than the previous release
  "beta8". No code change.
* Wed Jul 30 2014 fsundermeyer@opensuse.org
  New release DAPS 2.0~RC1:
- Language string in resulting filenames is no longer transformed to
  lowercase but taken as specified in MAIN (needed for Release Notes)
* Wed Jul 23 2014 fsundermeyer@opensuse.org
  New release DAPS 2.0~beta8:
- Added two stylesheets to daps-xslt/relnotes needed to build
  release-notes
* Thu Jun 26 2014 fsundermeyer@opensuse.org
  New release DAPS 2.0~beta7:
- Reverted the change that was introduced with beta6, since
  the libxml2-2 patches have been removed - they broke too many
  applications
- apart from a minor change in the automake setup this release is
  identical to beta5
* Wed May 21 2014 fsundermeyer@opensuse.org
  New release DAPS 2.0~beta6:
- Fixed fatal error:
  an update of libxml2 changed the behaviour of xmllint's
  entity handling which made it necessary to add --noent
  to the xmllint calls that check whether the sources are
  well-formed
* Wed Apr 23 2014 fsundermeyer@opensuse.org
  New release DAPS 2.0~beta5:
- fully supporting the suse-doc-style-checker (target stylecheck)
- fix for "online-docs": only tar'ing png and jpg if respective
  images are available
- fix for ticket #225 (Misleading error message when xml files do
  not reside in a directory named xml/)
- fix for ticket #218 (Improve error handling for --rootid
  parameter)
- added tests for targets "package-html and "package-pdf"
- resulting filenames for package-html and package-pdf can now
  be queried via "showvariable"
* Fri Mar 14 2014 fsundermeyer@opensuse.org
  New release DAPS 2.0~beta4:
- replace special characters (such as space or "/") from
  profiling attributes with "_" when generating the profiling
    directory path
- Made profiling depend on the DC file, too, to ensure a rebuild
  is triggered whenever the DC file changes
- STYLEIMG was set in a way that it had an incorrect value in case
  a fallback STYLEROOT directory was used
- Improved error message when not being able to determine DocBook
  version
- spec file:
  * require xmlstarlet
  * remove emacs-psgml recommendation
  * svg-dtd package has been renamed to svg-schema
* Sat Dec 21 2013 fsundermeyer@opensuse.org
  New release DAPS 2.0~beta3:
  Features:
- Use original HTML DocBook Stylesheets for txt output by default:
  * use custom stylesheets by setting TXT_USE_DBSTYLES to "no"
  Bugfixes:
  - STYLEROOT and FB_STYLEROOT definitions in the config files were
  checked even if values were specified on the command line
  (ticket #211)use custom stylesheets by setting TXT_USE_DBSTYLES
  to "no"
  - JSP result directory was incorrect when no profiled MAIN existed
  (ticket #212)
  - PDF was not copied to the result dir when running package-pdf
  - Improved error message when having specified a second bareword
  after the subcommand (ticket #185)
* Thu Dec 12 2013 fsundermeyer@opensuse.org
  Bugfix release DAPS 2.0~beta2:
  - two fixes for package-html and package-pdf:
  * ticket #208 package-pdf and package-html should support...
  * ticket #209 package-html --jsp is broken
* Fri Dec  6 2013 fsundermeyer@opensuse.org
  Version DAPS 2.0~beta1:
- First beta for a new major release
  Output targets:
  - --------------
  * the number of subcommands has been significantly reduced, see
    "daps --commands", "daps help" and "daps help <SUBCOMMAND>" for
    more information
  - "html-single" has been replaced by "html --single"
  - "jsp" has been replaced with "html --jsp"
  - "color-pdf" has been replaced by "pdf" (now produces color PDFS)
  - "pdf" has been replaced by "pdf --grayscale --cropmarks"
  - "projectfiles" and "projectgraphics" have been replaced with
    "list-srcfiles" (see daps help "list-srcfiles" for more options)
  - all dist-* commands have been removed
  - when calling deprecated targets, an error message hinting at a
    valid alternative (is existing) is shown
  * subcommand bigfile now generates a bigfile for the given rootid
    (rather than for the complate set); target bigfile-reduced has been
    dropped
  * subbcommands package-pdf and package-html now have switches
  - -dcoumentfiles, --desktopfiles and --pagefiles which generate
    the resource files for GNOME and KDE
  * new subcommands
  - "clean-package" removes all generated package data for the given
    DC-file. Generated images and profiled sources will _not_ be
    deleted.
  - "dapsenv" shows a list of the most important make variables
    and their values
  - "images" generates images only for a given rootid. Intended for
    debugging purposes
  - "package-src" (creates a tarball with profiled XML sources and
    images); switch --set-date allows to specify a build date (default
    date is "now")
  - "list-file" lists the filename that contains the ID specified
    with the mandatory paramater --rootid.
  * ePUB generation has been completely rewritten (pure make solution,
    no longer uses the ruby script from upstream); generated ePUBs
    now validate with epubcheck3.
  - added support for .mobi (Amzon Kindle format). Requires calibre.
    (ticket #98)
  * replaced support for HTML4 with support for HTML5 (--html5)
    xhtml remains the default, html4 is no longer supported
  * to nullify a CSS-file definition for HTML or EPUB (HTML_CSS or
    EPUB_CSS) from the DC-file, specify "--css none"
  Miscellaneous:
  - -------------
  * now supports XSLT processor saxon6 (in addition to xsltproc),
    specify with --xsltprocessor (default: xsltproc)
  * improved verbosity handling:
  - if output is not a terminal (e.g. pipe) only prints the
    resulting filename (-v0)
  - default verbosity shows a result message plus filename (-v1)
  - -v2 shows additional messages
  - -v3 shows the complete make output from make -j1 (commands are
    executed successively, not parallel)
  - --debug shows the complete make output from make -j1+x
    (commands are executed parallel; this also shows in the debug
    output)
  * added support for JPG images (ticket #101)
  * added support for a "static/" directory in STYLEROOT containing
    css, js and images taht are reference in the CSS and the
    stylesheets for HTML
  * New general switch --commands shows all available subcommands
  * if the XML sources are not well-formed, a meaningful error
    message is shown
  * xsltparameters have to be submitted as --param PARAM=VALUE or
  - -stringparam PARAM=VALUE (the "=" is mandatory, used to be
    a "space2 with DAPS 1.x)
  * output formats are only re-generated when the source files
    (xml, entity files or images) have changed. To force a rebuild
    run DAPS with --force or run a suitable clean command
  * added switches --author and --productname switches to daps-init
  Config file changes:
  - -------------------
  * New config file variables:
    COVERT_OPS_JPG:    command-line options for "convert" for converting
    jpg images to grayscale
    FOP_STACKSIZE:     set stacksize for fop (ticket #82)
    META, META_STR:    permanently run html and PDF builds with
  - -meta
    STATIC_DIR:        custom static directory
    XML_USER_CATALOGS: add custom catalogs to XML_CATALOG_FILES
    (ticket #99)
    XSLTPROCESSOR:     Use the specified XSLT processor
    (saxon6 or xsltproc)
  Code changes:
  - ------------
  * big makefile (common.mk) has been split into several small files
  - easier to maintain
  - improved performance by only loading makefiles that are needed
    for the given subcommand
  * added a comprehensive test suite to ensure better quality when
    releasing
  * no longer requires Bash 4--Bash 3 is sufficient
  Documentation:
  - -------------
  * Quickstart has been updated to cover DAPS 2.0
  * Update of User Guide is WIP
  * new Tutorial "How to Write an Article with DocBook and DAPS"
  Bugfixes:
  - --------
  Numerous bugfixes and improvements, among them:
  * #64 Split Makefiles
  * #66 daps: DC Files and Platform Dependant Paths
  * #73 Create PDFs for target locdrop if --def-file is specified
  * #82 Add config parameter for FOP (XEP?) stacksize
  * #85 Set a fixed <date/> date with package-src target
  * #98 Adjust EPUB Stylesheet to Suppot Kindle
  * #99 Support User Definied Catalogs by Setting XML_CATALOG_FILES...
  * #101 DAPS should support JPEG as a source file format
  * #103 Exit target package-source when there are missing images
  * #105 DAPS's sub-commands are somewhat inconsistent
  * #106 Enable overwriting xsltproc params
  * #108 Support FOP 1.1
  * #115 --css/HTML_CSS parameter is completely ignored if styleroot...
  * #116 Move font requirements from daps specfile to ...
  * #126 Add --show switch to checklink
  * #127 productinfo sometimes fails and is slow
  * #129 Get rid of native xsltproc calls
  * #136 daps Ignores Language in Document for Spell Checking
  * #138 DAPS makes it easier to create black/white PDFs than ...
  * #139 When trying to create a PDF file with malformed XSLT files...
  * #142 Saxon seems to have problems with NovDoc documents
  * #146 EPUB CRITICAL Error: No manual specific tmp dir
  * #147 EPUB validation error on callouts
  * #148 --meta only works when profiling
  * #159 Fatal Error in ePUB stylesheets
  * #163 JSP Stylesheets fail with saxon6
  * #165 FOP config file is unnecessary
  * #166 Reduce Logging Output of Apache's FOP
  * #171 Remove unnecessary "eval" statements in the DAPS code
  * #192 Create filenames in a single place
  * #196 EPUB does not build with saxon
  Known Issues:
  - ------------
  * the webhelp code hasn't been touched at all; webhelp will most
    likely not work
* Thu Jun  6 2013 fsundermeyer@opensuse.org
- Bugfix:
  * fixed failing dist-htmlsingle generation in online-docs
* Wed May 15 2013 fsundermeyer@opensuse.org
- Bugfixes:
  * option -m was missing when parsing the command line options
  * allow relative paths for --statdir and --export-dir
  * A custom static dir (--statdir) was not correctly copied/linked
    when no --static option was specified
  * fixed entitiy packaging in various targets
  * made automatic setting of HTML_CSS and EPUB_CSS more robust by
    allowing empty values when readlink fails
* Mon May 13 2013 fsundermeyer@opensuse.org
  Version 1.1.7 (Bugfix release):
  - Critical fix: Locdrop tarballs did not have profiled but original
    sources. This has been corrected
  - Made check for ROOTID  in lib/daps_functions more robust
* Mon May  6 2013 fsundermeyer@opensuse.org
- Bugfix: Typo in Varaiable name
- Created bnc #818744 requesting an online update
* Fri May  3 2013 fsundermeyer@opensuse.org
- Removed one unnecessary make info output which may produce
  irritating messages
* Thu May  2 2013 fsundermeyer@opensuse.org
  Version 1.1.6 (Bugfix release):
  * General:
  - reducing code by adding MAIN to the list of DOCFILES, by
    generating the list of ENTITY files globally and by
    using HTML_DIR for HTML. HTML-SINGLE and JSP
  * EPUB:
  - fixed critical error: a single tmp dir was used to generate
    different EPUB books
  - EPUB zip file is now generated from a file list extracted from
    OEBPS/content.opf. This ensures that only files referenced
    in the content.opf are packaged
  - Added fix for bug in DocBook stylesheets which generates an
    empty date entry in content.opf which causes a validation error
  - Improved CSS handling:
  - if no CSS file is specified on the command line or in the
    DC-file, the _first_ one found in <STYLEDIR>/epub/ is
    automatically used
  - --css now requires a parameter - if you do not want any CSS
    file to be used, specify "none": --css=none
  - EPUBs now validate with epubcheck 3.0
  * HTML:
  - if using the DocBook standard layout for resources
    <STYLEDIR>/images
    <STYLEDIR>/<FOO>.css
    it is no longer manfdatory to specify a CSS file on the
    command line or in the DC-file. DAPS will automatically use the
    _first_ *.css file in <STYLDIR>/ if none is specified
  - if using a static dir for resources
    <STYLEDIR>/static
    |-css
    |-js
    |-images
    you can now specify an alternative css file with --css or an
    alternative static dir with --statdir
  - this makes it possible to switch between stylsheets using the
    two different resource directory approaches without having to
    modify a DC-file
  - the --css parameter now requires an argument. If you want to
    use no stylesheet at all, specify --css=none
    NOTE: This update requires to run the first HTML, HTML-Single
    and JSP build after the update with the --clean switch in
    order to create a clean result directory.
  - if both variants (<STYLEDIR>/images and <STYLEDIR>/static
    exist, the static directory is automatically used
  * LOCDROP:
  - DC-files are delivered with a locdrop if --def-file is
    specified
  - NO_TRANS_FILES was not correctly computed
  - entity files were missing in packages
  * PACKAGE-SRC:
  - entity files were missing in packages
  * ONLINE-DOCS:
  - generating a uniquely named graphics tarball for each book
    (when export-dir is set) instead of one that gets overwritten
    with each build
* Tue Mar 26 2013 toms@suse.de
- Fixed bnc#811376
* Mon Mar 25 2013 fsundermeyer@opensuse.org
  * fix for EPUB validation bug (EPUB Mime-Type file ended with
  a newline which caused a validation error)
* Fri Mar 22 2013 fsundermeyer@opensuse.org
  * spec-file update: Version 1.77 or better of the Docook
  stylesheets is required
* Fri Mar 22 2013 fsundermeyer@opensuse.org
  Version 1.1.5 (Bugfix release)
  * fixed errors in EPUB generation (wrong paths in content.opf)
  EPUBs should now be viewable in all ePUB viewers
  * fixed two errors in target locdrop: no proper image tarball was
  generated and the notrans-tarball had a wrong path
  * added a missing conditional requirement (on $IMG_DIRECTORIES)
  for image building
  * fixed errors when building dist-{html,htmlsingle,jsp}
* Fri Mar 22 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Feb 13 2013 fsundermeyer@opensuse.org
  Version 1.1.4 (Bugfix Release):
  * Fixed target productinfo, which did not produce any output when
  ROOTID was not set
* Tue Feb  5 2013 fsundermeyer@opensuse.org
  Version 1.1.3 (Bugfix Release):
  * Added missing dependecies for Desktop/Document/Pagefile option
  (fix for ticket #122 package-pdf: --documentfiles fails with
  clean sources)
  * Added switch "xsltparam" for package-pdf and package-html
  (fix for ticket #121 package-pdf: --xsltparam missing)
* Thu Jan 17 2013 fsundermeyer@opensuse.org
  Version 1.1.2:
  * added support for the static/ directory used by the new
  stylesheets for HTML
  * re-enabled the new font-macros in spec-file (see commit from
  Mon Aug  6 15:53:53 UTC 2012 - pgajdos@suse.com) that got
  overwritten
* Mon Jan 14 2013 fsundermeyer@opensuse.org
  Version 1.1.1 (Bugfix Release):
  * fix for ticket #113 (daps-xslt/mallard/docbook.xsl missing)
  * fix for ticket #114 (package-html with easy file names wanted)
  * settings for BUILD_DIR in config files were ignored
* Fri Dec 21 2012 fsundermeyer@opensuse.org
  Version 1.1:
  daps-auto.pl:
  * a perl script to automatically build documents and deploy them
    to a remote machine via rsync
  EPUB:
  * completely rewrote the epub generating code
  * no longer needs an external script (db2epub.ruby) for
    epub-file generation - now everything is handled in
    make itself
  HTML/HTML-Single/JSP:
  * added a --clean switch which clears the directory
    before generating a new version
  Packaging:
  * completely rewrote the code for package-src
  - new option --set-date allows to set a publication date
    (default: current date)
  * new options for package-html and package-pdf
  - -desktopfiles: generates an archive with desktopfiles for KDE3
  - -documentfiles: generates a documnet file for KDE4/GNOME2
  - -pagefiles: generates a page file for GNOME3
  * completely rewrote online-docs
  - now automatically generates epub, color-pdf and single-html archive
  - new option --export-dir to specify a results directory
  * completely rewrote locdrop
  - new option --export-dir to specify a results directory
  Spellchecking:
  * no longer a stand-alone program
  * use "daps -d DC-file spellcheck" to check single files
    (--file option), complete documents (via DC-file) or
    parts of a document (vi ROOTID)
  * can be configured via config variables ASPELL_*
  Emacs macros for DocBook:
  * Now supports nxml-mode
  Documentation:
  * User Guide: significant additions
  Misc:
  * Added a --manifest option to dist-html which adds a manifest
    files containing the html-files in the same order as in the
    document
  * Replaced bash 4 only code with bash 3 compatible code
    (bash 4 is no longer a prerequisite for daps)
  Bugfixes:
  * Ticket #77 Lang variable ($LL) might not be set
  * Ticket #104 Inconsistent Tar Ball for dist-graphics
  * Corrected the webhelp.indexer.language setting
  * a misplaced >/dev/null prevented the svg2svg conversion,
    resulting in 0 byte SVGs
  * added proper error handling to setfiles, sourcefiles, docfiles
    computing
  * html-single output in a separate htmlsingle/ directory
  * Raised FOP_STACK to 2048k, because otherwise FOP builds on
    x86_64 fail
  * Fixed a bug in listing the double images. backup images like
    foo.svg~ or foo.svg.~ were listed, too
  * EPUB generation failed when no CSS file was specified. This
    is fixed now
  * Fixed sed statements for preserving and recovering entities;
    the former statements did not match all entity declarations
    possible and recovering was error-prone
  * Only use optipng when it is available
  * Fixed targets warn-images and warn-cap
* Mon Aug  6 2012 pgajdos@suse.com
- prepare spec file for dropping SuSEconfig.fonts (openFATE#313536)
* Thu May  3 2012 fsundermeyer@opensuse.org
  Version 1.0.2 (Bugfix Release):
  * Important:
  - in order to avoid confusion with short options for daps itself
    (such as -d for --docconfig and --draft),
    the subcommands only support long options now. The following
    short options for subcommands are no longer supported:
  - c (use --comments)
  - d (use --draft)
  - f (use --file)
  - m (use --meta)
  - n (use --name)
  - p (use --pretty)
  - r (use --remarks)
  - s (use --show)
  - the only short option that will remain is -h (help)
  * Bugfixes:
  - added proper help texts for subcommands
  - target warn-images did not work
  - target missinggraphics did not show all missing images
  - daps failed with a useless error message when $MAIN was not
    well-formed. The fix produces a useful error message now
  - --remarks option did not work with DocBook stylesheets
  - paths specified on the command line or the config file had to
    be absolute. The fix now allows to also specify relative paths
    for all configurable directories and files
  - COMMENTS_STR, DRAFT_STR and REMARK_STR were not correctly unset
    when one of these modes was not set on the command line but
    implied by another mode (e.g. --meta). The result was a wrong
    filename
  - target webhelp-dir-name was missing
  - draft.png was not shown in PDF/HTML draft builds when using the
    DocBook Stylesheets
  - Due to a variable name mismatch, the --name option did not work
    properly
  - target showvariable exited with an error if requested variable
    was empty
  - config options FOP_CONFIG and XEP_CONFIG were not used. The fix
    renames them to FOP_CONFIG_FILE and XEP_CONFIG_FILE - these
    variables are used in the wrapper scripts
  - FOP_WRAPPER and XEP_WRAPPER were not set correctly when
    DAPSROOT was set
  - disabled Permalink generation for PDFs (this is an HTML-only
    feature)
  - images were not cerrectly references for target jsp
  - the DEF file was not correctly packaged in target locdrop
  - fixed webhelp target. Wildcards do not work in classpath
    expression, resolved them with $(wildcard $(firstword())
  - Warning message "DEF file is missing" was issued for targets
    that do not have a --def-file option
  - targets package-html and package-pdf failed with an error on
    desktop files generation
  - target remaininggraphics always returned an empty list
  - SVG to SVG conversions generated useless error messages
  * Stylesheets:
  - removed obsolete stuff for @role=productname,
    productnumber, or productnameref
  * Documentation:
  - Quick Start Guide: Finished
  - User Guide: Significant additions, but still work in progress
  - Updated README.upgrade_from_susedoc_4.x
* Tue Apr  3 2012 fsundermeyer@opensuse.org
  Version 1.0:
  Bugfix:
  - Use XEP/FOP wrapper scripts by default
* Mon Apr  2 2012 fsundermeyer@opensuse.org
  version 1.0 RC5:
  * Bugfix:
  - Setting stack size for FOP to 512k in wrapper script, otherwise
    builds on i586 fail during hyphenation
* Mon Apr  2 2012 fsundermeyer@opensuse.org
  Version 1.0 RC4
  * Bugfix:
  - Not all links were dereferenced with --static
* Fri Mar 30 2012 fsundermeyer@opensuse.org
  Version 1.0 RC3
  * Bugfixes:
  - Issuing hint on missing formatter scripts only when verbosity
    is >= 1
  - spec-file: Fixed typo on suse-xsl-stylesheet recommends
    python-xml needs to be a general requirement
  - fixed path to callouts and style images for FO
  * Lots of minor documentation fixes/enhancements
* Thu Mar 29 2012 fsundermeyer@opensuse.org
  Version 1.0 RC2
  * Bugfixes:
  - issue a hint rather than exiting when XEP/FOP_WRAPPER do not
    exist
  - daps_xslt/yelp/*.xsl was not installed by make install
* Wed Mar 28 2012 fsundermeyer@opensuse.org
  Version 1.0 RC1
  * Bugfixes:
  - fixed minor package building issues
  - inkscape always returns 0, even in case of an error. Added
    a workaround, so daps now exits when an image conversion with
    inkscape fails
  - --main option should work now
  - Fixed errors on setting the fallback stylesheets
  - comments and remarks did not show up in the docs when requested
    (again ;-(( ) - this is fixed now
  * much better error handling - daps will now exit when wrong paths
  or a non existing ROOTID are entered in the user config file
  or the DC file
  * significant enhancements to the Documentation
  (Reference & Quickstart)
* Tue Mar 20 2012 fsundermeyer@opensuse.org
  * Bugfix: Target for index generation had wrong ending
  (.idx instead of .ind)
* Fri Mar 16 2012 fsundermeyer@opensuse.org
  * Bugfix: Typo in Makefile caused wrong catalog entries
* Thu Mar 15 2012 fsundermeyer@opensuse.org
  * showvariable now only shows the result to make it better suited
  for script usage
* Thu Mar 15 2012 fsundermeyer@opensuse.org
  Version 1.0beta2:
  * Bugfix:
  Finally found the correct solution for adding/removing catalog
  entries in the spec file
  * Enhancement: webhelp suppport
* Wed Mar  7 2012 fsundermeyer@opensuse.org
  Version 1.0beta1:
  * Rebuild large parts to make DAPS distribution-independent.
  - rewrote Makefile for automake/autoconf
    => configure; make; make install is now supported
  - thorough cross-distribution testing is still needed, basic tests
    have been run on RedHat, Debian and Ubuntu
  * removal of custom stylesheets
  DAPS no longer uses the SUSE stylesheets as a default. It even no
  longer contains the SUSE stylesheets - they are now available as a
  separate package (suse-xsl-stylesheets in Documentation:Tools).
  - By default DAPS uses the generic DocBook stylesheets now
  - Custom stylesheets such as the SUSE stylesheets can be used by
    specifying up to four parameters on the command line/the config
    files:
  * Styleroot:
    Directory containing the custom stylesheets. Must have the same
    directory structure as the original DocBook stylesheet root
    directory. Does _not_ need to contain stylesheets for all output
    formats. If stylesheets are not found, DAPS will automatically
    fall back to the DocBook stylesheets.
  - Variable: STYLEROOT
  - Parameter: --styleroot
  - Value: absolute path to directory
  * Fallback styleroot
    Custom fallback styleroot. If DAPS cannot find styles for the
    given output format, it will automatically fall back to the
    DocBook stylesheets. This config option will add a custom
    fallback directory with higher priority. The DocBook stylesheets
    will remain as a last resort, however.
  - Variable: FALLBACK_STYLEROOT
  - Parameter: --fb_styleroot
  - Value: absolute path to directory
  * CSS files:
    Specify CSS files for HTML and/or CSS. By default no CSS file
    will be used.
  - Variables: HTML_CSS, EPUB_CSS
  - Parameter: --css for html and epub targets
    (daps -d <DC> html--css <CSS> )
  - Value: absolute path to file
  * rewrote FOP formatter handling - both supported formatters (FOP/XEP) are
  now controlled by the following variables:
  * _WRAPPER (wrapper script, libexec/daps-fop, libexec/daps-xep by default)
  * _CONFIG (xml config file, etc/daps/xep/xep-daps.xml and
    etc/daps/fop/fop-daps.xml by default. A specific fop-daps.xml
    is installed for RedHat and SUSE by default)
  * _OPTIONS (Command line options)
  * renaming of parameters and variables
  In order to make parameters and variables "self-speaking" the
  following has been renamed:
  - File ENV-file to DC-file (doc config file)
  - Variable BASE_DIR to DOC_DIR (doc dir) => Terminology!
  - Variable DTDROOT to DAPSROOT (daps installation directory)
  - Variable FOP_TYPE to FORMATTER
  - command line switch --fop to --formatter
  - command line switch -e/--envfile has been renamed to
  - d/--docconfig (-e/--envfile will still be supported)
  * global parameter --base_dir no longer supported
  Instead of specifying --base_dir with daps, you now need to specify a
  full path (either relative or absolute) to the DC-file. However, the
  "magic" that automatically tries to determine the path to a DC-file
  when you do not specify a path or not even a DC file, still applies.
  Therefore you only need to specify a valid path to the DC-file in
  cases where you would have used --base_dir with previous DAPS
  versions.
  * --main parameter / MAIN
  Instead of calling daps with -d/--docconfig you can also directly
  specify a MAIN with --main=<PATH>. You need to specify a valid
  relative or absolute path. If you just specify a
  file name, ./xml/$MAIN is automatically assumed.
  * packaging
  The former DAPS version has been split into two packages:
  - daps
  - suse-xsl-stylesheets (SUSE stylesheets, NovDOC DTD, SUSE aspell
    wordlist)
  * other DAPS changes since 0.9.2 in brief:
  - stylesheet images have been moved to fit the directory structure used
    in the original stylesheets
  - new variable STYLEDEVEL which can be used when developing stylesheets.
    STYLEDEVEL _always_ takes precedence over STYLEROOT and can be set in
    $USER_CONFIG
  - Rewrote handling of profiling variables PROFARCH, PROFCONDITION,
    PROFVENDOR, PROFOS - all 4 are now fully supported (formerly only
    PROFOS and PROFARCH were fully supported)
  - created catalog entry to resolve stylesheets in daps_xslt
  - daps init has been moved to a separate script bin/daps-init
  - each SUSE stylesheet file now contains a short overview of purpose
    and parameters
  - lots of stylesheet bugfixes
  - license: GPL 2.0 or 3.0 at your choice
  - fixed target man for man-page generation; man pages are not gzip'ed
    by default (unless you specify --nogzip); manpage subdirectories
    (man1, man2,...) are no longer created by default, but can rather be
    enabled via the --subdirs switch
  - new parameter --check for target epub checks build with epubcheck
  - added very basic DocBook5 support (with xslt 1.0 stylesheets only)
    still a lot to do on this front
  - Default HTML format is now XHTML 1.0 (instead of HTML 4.01). Use
  - -html4 to generate HTML 4.01
  - auto generate SUSE HTML4 stylesheets from XHTML stylesheets
  - binaries that are only called from withion make have been moved to
    libexec/
* Mon Jan  9 2012 toms@suse.de
- Really fixed bnc#739213,
- Added COPYING-{2.0,3.0} files
* Wed Dec 28 2011 ke@suse.de
- Remove fetch_source.
* Wed Dec 28 2011 ke@suse.de
- BuildRequire exiftool that's now available as a subpackage on
  Factory.
* Thu Dec 15 2011 fsundermeyer@opensuse.org
  New version 0.9.2
- BUGFIXES:
  * fixed misspelled variablename in fo generating target
  * remarks in HTML and PDF builds were only shown when comments
    were turned on, too. This had been fixed earlier but the fix
    seems to have been reverted by mistake. Re-enabled the fix in
    the inline.xslt stxlesheets for fo and html
- -r/--remarls now implies draft mode
- -m/--meta now implies draft mode but does not imply remarks
  anymore
* Thu Dec 15 2011 ke@suse.de
- Set license to GPL-2.0+.
* Thu Dec 15 2011 ke@suse.de
- On 12.1, BuildRequire perl-Image-ExifTool.
* Fri Dec  9 2011 fsundermeyer@opensuse.org
- BUGFIX: Misspelled variable name in fo generation for FOP
- Styleshhet changes:
  * added first draft of release notes stylesheets
* Wed Dec  7 2011 fsundermeyer@opensuse.org
- Stylesheet changes:
  Fixed bugs:
  * bnc#573835: pdf-color: title in PDF properties too general
  * bnc#703483: FOP: No Hyphenation?
  * bnc#706452: FOP: Too much Whitespace Behind <ulink> and <filename>
  * bnc#711526: Layout: sect3 can not be distinguished from a sect4
  * bnc#719848: daps stylesheets: Make metadata for PDF draft mode optional
- Program changes:
  * New version 0.9.1
  * NEW FEATURES:
  - "daps -h <subcommand>" now shows help for subcommand
  - New config option XSLTPARAM / cmdline switch --xsltparam:
    can be used to overwrite one or more stylesheet
    parameters. Using that option/switch it is possible to change
    the pagesize, pageformat, alignment, margins, etc. etc.
    without having to rewrite the stylesheets directly
  - subcommand getimages can now be run with a rootid or a filename
  - subcommands getimages and checklink can now be invoked without
    a filename or a rootid - in this case the rootid provided by
    the ENV-file is used
  - new general command line switch --version
  - new switch -m/--meta for pdf builds (adds same functionality as
    for the html builds)
  * completely rewrote lib/daps_functions:
  - now has a generic option parser
  - functions setup_builddir and format_options have been
    combined into one function called init_env
  - one single function that invokes make: call_make
  - logging can be turned on/off within each function invoking
    call_make by setting WRITE_LOG to 1/0 (default: 1 (on))
  - the make command is now set up here rather than in bin/daps
  - getimages now uses make to create the image list (rather than
    using /usr/bin/xml)
  - new function no_opts for subcommands that have no command line
    switches
  * pretty printing has been moved from lib/daps_functions into the
    makefiles
  * BUGFIXES:
  - We now do an early! check whether a subcommand is correct
    or not function run_subcmds has therefore been replaced by an
    associative hash; the hash's key/value pairs can be eval'd to
    call the function
  - .fo files will always be regenerated by using PHONY targets
    This also keeps the .fo file, which is desireable for debugging
    purposes
* Fri Oct  7 2011 fsundermeyer@opensuse.org
- Bugfixes on .document and .desktop file generation
* Fri Oct  7 2011 toms@suse.de
- Updated Quick Start/Flyer design
* Thu Oct  6 2011 fsundermeyer@opensuse.org
- Bugfix: image copying on static html builds
* Thu Oct  6 2011 fsundermeyer@opensuse.org
- Bugfix: css file was not properly copied when using --static on
  HTML builds
* Fri Sep 30 2011 fsundermeyer@opensuse.org
- Bugfixing HTML generation. Copying/linking images and CSS made
  problems when old builöds were present. This fix ensures images/css
  files get removed before trying to create them
* Fri Sep 30 2011 fsundermeyer@opensuse.org
  Beta 8:
- new option "--static" for html builds copies images and css files
  rather than linking them (which is the default)
- document-files-html / document-files-pdf / desktop-files now only
  generate the desktop files rather than creating tarballs
  * tarballs are generated with dist-document-files-html, dist-...
  * document-files-dir-name, desktop-files-dir-name show the
    directory names for the generated desktop files
- new file names for PDFs:
  color: ($BOOK|$ROOTID)_$LANG.pdf
  print: ($BOOK|$ROOTID)-print_$LANG.pdf
- new option --def-file=DEFFILE for target package-src. If specified
  also adds all ENV files referenced in the DEF-file to the tarball
- new option --def-file=DEFFILE for target locdrop adds the DEF-file
  to the notrans tarball
- Bugfix:
  * get name targets (pdf-name, html-dir-name,...) now support
    options --name, --rootid, -cdr
* Mon Sep 26 2011 fsundermeyer@opensuse.org
- spec file changes so daps builds for SLE 11 / 11.1:
  * checkbot is a recommendation for SLE
  * require python-xml for < 1120
  * replace make_install macro with a literal make install call,
    since 11.1/SLE 11 do not have the macro
- use the tar option --transform instead of --xform in order to be
  compatible with older tar versions
- Bugfix Makefile: global option -d has been replaced with --debug
* Mon Sep 26 2011 fsundermeyer@opensuse.org
- target validate now also warns about missing graphics
- Bugfix: verbosity switch -v works correctly now
* Tue Sep 20 2011 fsundermeyer@opensuse.org
- verbosity can now also be set to "0" on the command line (needed
  for scripting)
- renamed "--verbose" switch to "--verbosity"
- Specfile: Requires: fam
* Mon Sep 19 2011 fsundermeyer@opensuse.org
- Specfile: fixed %%{ext_man}
- fetch_source now also copies the spec file if needed
* Mon Sep 19 2011 fsundermeyer@opensuse.org
- Completely rewrote the verbosity stuff:
  * Verbosity none: only display on line with result (default)
  * Verbosity 1 (-v, --verbose=1): print the most important target results
  * Verbosity 2 (-vv --verbose=2): print all commands called by make
  * Default verbosity level can be overwritten in ~/.daps/config via
    VERBOSITY=(0|1|2)
- General option -d is no longer supported to avoid confusion with
  subcommand option -d (draft mode) - use --debug instead
- Replaced target clean-book with clean-results
- Updated BUGS and TODO
- Stylesheets:
  * fixed bnc#573835 (PDF metadata)
- Bugfix: BUILD_DIR is now set in the makefiles
- Packaging:
  * added script that generates the source tarball via
    svn export
  * added %%{ext_man} to spec file
* Mon Sep 19 2011 toms@suse.de
- Applied spec file changes after Jan Engelhardt's mail on
  opensuse-packaging:
  (see also http://en.opensuse.org/openSUSE:Specfile_guidelines)
- removal of '# norootforbuild'
- removal of Authors list, no longer desired in factory
- removal of %%clean section, no longer required
- adding %%{?_smp_mflags} whereever there is none
* Thu Sep 15 2011 fsundermeyer@opensuse.org
  Beta 7
- DAPS now supports EPS (will be converted to PDF and PNG) and
  PDF images; SVG sources can also be converted into PDF
  - new dependencies for EPS and PDF support in spec file:
    ghostscript-library, poppler tools
- completely revised images.mk to increase readability and improved
  inline documentation
- sped up png optimization with optipng by using optimization level
  2 rather than 8: almost no difference in file-size, but huge
  difference in speed
- Bugfixes:
  - rewrote profiling, since the changes from beta6 introduced
    an error that prevented profiling on changed files
* Mon Sep 12 2011 fsundermeyer@opensuse.org
- Bugfix: remove duplicate entries in SRCFILE list in common.mk
    (using sort)
* Fri Sep  9 2011 fsundermeyer@opensuse.org
  Beta 6
- DAPS can now use XML source files with any suffix
  (not only *.xml--the KDE  project for example is using *.docbook);
-  set default values for PROFOS and PROFARCH in case they are empty
- Bugfixes:
  * target validate: call function comments_remarks rather than
    build_generic
  * target locdrop: correct docmanager command; warn if no file has
    doc:trans=yes
* Thu Sep  8 2011 fsundermeyer@opensuse.org
- this time for real:  adjusted spec file so daps also builds for
  openSUSE_Evergreen_11.2
* Thu Sep  8 2011 fsundermeyer@opensuse.org
  Beta 5
- print filename and ids for chapter and section headlines
  in draft mode
- added 301 and 302 codes to dontwarn options of checkbot
- start image viewer in target getimages only when there are images
* Thu Aug 11 2011 fsundermeyer@opensuse.org
- Reverted previous change since that causes trouble with
  11.3
* Thu Aug 11 2011 fsundermeyer@opensuse.org
- Adjusted spec file so daps also builds for openSUSE_Evergreen_11.2
* Thu Aug 11 2011 fsundermeyer@opensuse.org
- Using a stylesheet rather than the buggy /usr/bin/xml to get the
  rootid of a file for target checklink
* Wed Aug 10 2011 toms@suse.de
- Changed standard layout from Novell to SUSE (1st attempt)
* Mon Aug  8 2011 fsundermeyer@opensuse.org
- BUGFIX: target checklink now exits when no rootid or filename is
    specified; rootid from ENVfile is ignored
* Fri Aug  5 2011 fsundermeyer@opensuse.org
- BUGFIX: Profiling was only redone when the _xml_ source files had
    changed, not when the entity files had changed - added a
    dependency on *.ent to the profiling target $(PROFILES)
    to fix this
* Fri Aug  5 2011 fsundermeyer@opensuse.org
- BUGFIX: getimages function did not work in verbose or
    debug mode
* Thu Aug  4 2011 fsundermeyer@opensuse.org
- adding a workaround for the crappy xml program that has no catalog
  support
* Thu Aug  4 2011 fsundermeyer@opensuse.org
- Colored output is now automatically disabled when not being on a
  Terminal - so you now pipe daps commands to other programs
  (e.g. a PDF Viewer or a browser)
* Thu Aug  4 2011 fsundermeyer@opensuse.org
- Added option --file to target checklink
* Mon Aug  1 2011 fsundermeyer@opensuse.org
- Changing target validate again: when being called explicitly, it
  now always checks profiled sources _with remarks_ ($REMARKS is
  set to 1). Options -r and -c have been removed again.
- Bugfix: Using $@ instead of $SCMD_ARGS in getopts calls in
  lib/daps_functions
* Mon Aug  1 2011 fsundermeyer@opensuse.org
- we need to be able to install daps and susedoc in parallel
  internally, so removed the Obsoletes: susedoc statement
  from the spec file
- target validate can now be called with -r and -c, too
* Thu Jul 28 2011 fsundermeyer@opensuse.org
- Bugfix: daps-susespell: the extra-dict was not invoked correctly
* Tue Jul 26 2011 fsundermeyer@opensuse.org
- BUGFIX: DAPS_ENV_NAME must not be set in config
* Tue Jul 26 2011 fsundermeyer@opensuse.org
  Beta 4
- spec file:
  * removed obsolete python dependencies (they moved to daps-docmanager)
  * obsoletes susedoc
  * recommends daps-docmanager and aspell+en dicts
- daps-susespell now has a man page and supports additional options
  - -lang and --dict
* Mon Jul 25 2011 fsundermeyer@opensuse.org
- daps-susespell can now check multiple files
- Bugfix in lib/docbook-macros: Element typo (arearefs)
* Mon Jul 25 2011 fsundermeyer@opensuse.org
- Target checklink (chklnk, jana) now supports --rootid
* Mon Jul 25 2011 fsundermeyer@opensuse.org
- Added exits after target calls
- Improved help/README on target init
* Fri Jul 22 2011 fsundermeyer@opensuse.org
- Bugfix: daps init help now works correctly
- Added a quickstart README
- Improved error handling and verbose output
- The majority of targets now write a logfile
* Thu Jul 21 2011 fsundermeyer@opensuse.org
  Beta 3
- Bugfix: USEMETA now works correctly
- added new binary daps-susepell (Spellchecker)
- added new target getimages
* Wed Jul 20 2011 fsundermeyer@opensuse.org
- Bugfixes
  * replaced @VERSION@ and @DATE@ in daps man page
  * daps error messages now go to STDERR
  * DTDROOT/xslt (STYLEDEVEL) is the new defaul-LAYOUTROOT
  * Fixed the long-standing bug that required to activate remarks
    _and_ comments in order to see remarks
- new optional config option for ~/.daps/config: DAPS_ENV_DEFAULT
  to specify a default ENVFILE. If set, will be automatically used
  unless an alternative ENVFILE is specified on the commandline via
  - e/--envfile or via a sourced ENVFILE by DAPS_ENV_NAME
- added new target showenv that print variables ENVFILE and BASE_DIR;
  can output more variables if needed
* Tue Jul 19 2011 fsundermeyer@opensuse.org
- format_options needs to be called from the main call_make functions
* Tue Jul 19 2011 fsundermeyer@opensuse.org
- Bugfix: Sourcing an ENV with DAPS_ENV_NAME set did not work
- Bugfix: Command line arguments for comments, drafts and remarks
  were not properly exported
* Thu Jul 14 2011 fsundermeyer@opensuse.org
- Moved daps-xmlformat to bin
- specifying a default ENVfile with DAPS_ENV_NAME=<ENV> in
  ~/.daps/config now also works when BASE_DIR is specified
* Thu Jul 14 2011 fsundermeyer@opensuse.org
- added a new subcommend: init, which creates a working environment incl.
  an ENV file and a xml/MAIN
* Wed Jul 13 2011 fsundermeyer@opensuse.org
- Fixed a bug in xslt/misc/get-all-used-files.xsl; common.mk needed
  to be changed, too
- error messages are directed to /dev/null when calling make_nolog
* Wed Jul 13 2011 fsundermeyer@opensuse.org
- LOG_DIR was not exported
- when running showvariable the date was always printed with the
  result - this is hopefully fixed now
- Expanded ENV conversion example in the upgrade README
* Wed Jul 13 2011 fsundermeyer@opensuse.org
- replaced the last remnants of "susedoc" with "daps"
* Wed Jul 13 2011 fsundermeyer@opensuse.org
- Removed copy pdf from package PDF
* Wed Jul 13 2011 fsundermeyer@opensuse.org
- fixed dist-graphics (images were packed with absolute path)
- fixed HTML-USED (imagelist was wrong)
- fixed USED (removed double entries)
- added --extra-files option to package-src in order to be able
  to pack additional ENVfiles
- added --fop option for package-pdf
- packaging targets now have their own function in daps_functions
* Mon Jul 11 2011 fsundermeyer@opensuse.org
- lib/daps_functions: Fixed xep wrapper call
  (susedoc-xep -> daps-xep)
* Fri Jul  8 2011 fsundermeyer@opensuse.org
- common.mk: Another fix for projectfiles/reminingfiles: $INCLUDED
  must include $MAIN, otherwise getentityname.py will be called with
  an empty $INCLUDED if the book only contains a single MAIN file
* Fri Jul  8 2011 fsundermeyer@opensuse.org
- common.mk: MAIN was missing in projectfiles; fixed remainingfiles
- added TODO for man page generation, init target
* Fri Jul  8 2011 ke@suse.de
- Remove my name from the authors' list.
* Thu Jul  7 2011 fsundermeyer@opensuse.org
- Changed the IDs in /etc/xml/suse-catalog.xml to something that
  makes more sense
* Thu Jul  7 2011 fsundermeyer@opensuse.org
-  Fix for -e/-b options
* Wed Jul  6 2011 fsundermeyer@opensuse.org
- added short options -b and -e for basedir and envfile
- reformatted help
* Fri Jul  1 2011 fsundermeyer@opensuse.org
  First beta of the DocBook Authoring and Publishing Suite (daps),
  the successor of susedoc. Major changes compared to susedoc:
  * make calls have been replaced by central wrapper script daps
  with svn/git style syntax
  * Independent from shell environment
  * All output generated by susedoc is placed in <wd>/build (default)
  or in <BUILDDIR> (can be spcified on the copmmand line)
  * Strict separation between generated content and source files
  * Typical Linux configuration style hierarchy established:
  - System wide configuration ( /etc/daps/config )
  - User configuration ( ~/.daps/config )
  - Book specific (ENVfile)
  - Command line
  * STDOUT output much less verbose, log file is written
  * Debugging function
  * bugfixes
